@@ -23,17 +23,15 @@ import abc
 import collections
 import glob
 import os
-
 import shutil
+from typing import Any, Callable
 
-import molecule.command
-import molecule.scenarios
-from molecule import config
-from molecule import logger
-from molecule import util
 import click
 from click_help_colors import HelpColorsCommand, HelpColorsGroup
 
+import molecule.command
+import molecule.scenarios
+from molecule import config, logger, util
 
 LOG = logger.get_logger(__name__)
 MOLECULE_GLOB = os.environ.get("MOLECULE_GLOB", "molecule/*/molecule.yml")
@@ -232,8 +230,8 @@ def click_group_ex():
     )
 
 
-def click_command_ex():
+def click_command_ex() -> Callable[[Callable[..., Any]], click.Command]:
     """Return extended version of click.command()."""
-    return click.command(
+    return click.command(  # type: ignore
         cls=HelpColorsCommand, help_headers_color="yellow", help_options_color="green"
     )
