@@ -24,8 +24,7 @@ from __future__ import print_function
 import click
 import tabulate
 
-from molecule import logger
-from molecule import api
+from molecule import api, logger
 from molecule.command import base
 
 LOG = logger.get_logger(__name__)
