@@ -23,8 +23,7 @@ import re
 
 import click
 
-from molecule import logger
-from molecule import util
+from molecule import logger, util
 from molecule.command import base
 
 LOG = logger.get_logger(__name__)
