@@ -19,17 +19,14 @@
 #  DEALINGS IN THE SOFTWARE.
 """Ansible Provisioner Module."""
 
-import copy
 import collections
+import copy
 import os
 import shutil
 
-from molecule import logger
-from molecule import util
+from molecule import logger, util
 from molecule.api import drivers
-from molecule.provisioner import base
-from molecule.provisioner import ansible_playbook
-from molecule.provisioner import ansible_playbooks
+from molecule.provisioner import ansible_playbook, ansible_playbooks, base
 
 LOG = logger.get_logger(__name__)
 
@@ -414,7 +411,7 @@ class Ansible(base.Base):
     def default_env(self):
         # Finds if the current project is part of an ansible_collections hierarchy
         collection_indicator = "ansible_collections"
-        collections_paths_list = [
+        collections_path_list = [
             util.abs_path(
                 os.path.join(self._config.scenario.ephemeral_directory, "collections")
             )
@@ -423,8 +420,8 @@ class Ansible(base.Base):
             collection_path, right = self._config.project_directory.split(
                 collection_indicator
             )
-            collections_paths_list.append(util.abs_path(collection_path))
-        collections_paths_list.extend(
+            collections_path_list.append(util.abs_path(collection_path))
+        collections_path_list.extend(
             [
                 util.abs_path(
                     os.path.join(os.path.expanduser("~"), ".ansible/collections")
@@ -454,7 +451,7 @@ class Ansible(base.Base):
                         "/etc/ansible/roles",
                     ]
                 ),
-                "ANSIBLE_COLLECTIONS_PATHS": ":".join(collections_paths_list),
+                self._config.ansible_collections_path: ":".join(collections_path_list),
                 "ANSIBLE_LIBRARY": ":".join(self._get_modules_directories()),
                 "ANSIBLE_FILTER_PLUGINS": ":".join(
                     [
