@@ -21,8 +21,7 @@
 
 import sh
 
-from molecule import logger
-from molecule import util
+from molecule import logger, util
 
 LOG = logger.get_logger(__name__)
 
