@@ -19,40 +19,40 @@
 #  DEALINGS IN THE SOFTWARE.
 """Molecule Shell Module."""
 
+import sys
+
 import click
 import click_completion
 import colorama
 import pkg_resources
-import sys
-
-from ansible.release import __version__ as ansible_version
+from click_help_colors import _colorize
 
 import molecule
 from molecule import command
+from molecule.command.base import click_group_ex
 from molecule.config import MOLECULE_DEBUG
 from molecule.logger import should_do_markup
 from molecule.util import lookup_config_file
-from molecule.command.base import click_group_ex
-from click_help_colors import _colorize
 
 click_completion.init()
 colorama.init(autoreset=True, strip=not should_do_markup())
 
-LOCAL_CONFIG = lookup_config_file(".config/molecule/config.yml")
+LOCAL_CONFIG_SEARCH = ".config/molecule/config.yml"
+LOCAL_CONFIG = lookup_config_file(LOCAL_CONFIG_SEARCH)
 
 
 ENV_FILE = ".env.yml"
 
 
-def _version_string():
+def _version_string() -> str:
 
     v = pkg_resources.parse_version(molecule.__version__)
-    color = "bright_yellow" if v.is_prerelease else "green"
+    color = "bright_yellow" if v.is_prerelease else "green"  # type: ignore
     msg = "molecule %s\n" % _colorize(molecule.__version__, color)
     msg += _colorize(
         "   ansible==%s python==%s.%s"
         % (
-            pkg_resources.parse_version(ansible_version),
+            pkg_resources.get_distribution("ansible").version,
             sys.version_info[0],
             sys.version_info[1],
         ),
@@ -61,7 +61,7 @@ def _version_string():
     return msg
 
 
-@click_group_ex()
+@click_group_ex()  # type: ignore
 @click.option(
     "--debug/--no-debug",
     default=MOLECULE_DEBUG,
@@ -74,9 +74,11 @@ def _version_string():
     help=(
         "Path to a base config.  If provided Molecule will load "
         "this config first, and deep merge each scenario's "
-        "molecule.yml on top. By default is looking for config in current "
-        "VCS repository and if not found it will look on user home. ({})"
-    ).format(LOCAL_CONFIG),
+        "molecule.yml on top. By default Molecule is looking for "
+        "'{}' "
+        "in current VCS repository and if not found it will look "
+        "in user home. ({})"
+    ).format(LOCAL_CONFIG_SEARCH, LOCAL_CONFIG),
 )
 @click.option(
     "--env-file",
@@ -86,7 +88,7 @@ def _version_string():
 )
 @click.version_option(
     prog_name="molecule", version=molecule.__version__, message=_version_string()
-)
+)  # type: ignore
 @click.pass_context
 def main(ctx, debug, base_config, env_file):  # pragma: no cover
     """
