@@ -20,18 +20,16 @@
 
 from __future__ import print_function
 
-from collections.abc import Mapping
 import contextlib
 import fnmatch
-import jinja2
 import os
 import re
 import sys
-
-
+from collections.abc import Mapping
 from functools import lru_cache  # noqa
 
 import colorama
+import jinja2
 import yaml
 
 from molecule.logger import get_logger
@@ -344,7 +342,7 @@ def _parallelize_platforms(config, run_uuid):
     return [parallelize(platform) for platform in config["platforms"]]
 
 
-def find_vcs_root(test, dirs=(".git", ".hg", ".svn"), default=None):
+def find_vcs_root(test, dirs=(".git", ".hg", ".svn"), default=None) -> str:
     """Return current repository root directory."""
     prev, test = None, os.path.abspath(test)
     while prev != test:
@@ -354,7 +352,7 @@ def find_vcs_root(test, dirs=(".git", ".hg", ".svn"), default=None):
     return default
 
 
-def lookup_config_file(filename):
+def lookup_config_file(filename: str) -> str:
     """Return config file PATH."""
     for path in [find_vcs_root(os.getcwd(), default="~"), "~"]:
         f = os.path.expanduser("%s/%s" % (path, filename))
